/* ========================================
 *
 * PSoC:  PSoC CY8C5888LTI-5LP
 * Kit: CY8CKIT-059
 * LED Sign-Control Software for 5-by-7 or 8-by-8 LED modules
 * LED module:  Common Anode for rows, common cathode for columns.
 * Jonathan A Titus, Herriman, UT 2018
 * 07-23-2018 at 1800H US MDT
 * Released as open-source code.
 * No restrictions on use
 * Please acknowledge author in any derived code!
 *
 * ========================================
*/
#include "project.h"

    uint8 BlankColumns;             //Number of blank columns to shift out
    uint8 BlankIndex;               //Counter for blank-column shifts
    uint8 CharData;
    uint8 CharGenRow;
    uint8 CharIndex;
    uint8 CharToDisplay[16];        //Array of ASCII characters to display
    uint8 LED_Row_Drive;            //Sets the FET to drive an LED row
    uint8 LoopCount;
    uint8 Numb_of_Char;             //Number of characters to display
    uint8 RowControl;
    uint8 ShiftIndex;
    
    uint16 EEPROM_Address;

    int main(void)
    {
    CharToDisplay[0] = 'H';         //Charatcters to display, max 15 per row
    CharToDisplay[1] = 'i';
    CharToDisplay[2] = ' ';
    CharToDisplay[3] = 'J';
    CharToDisplay[4] = 'o';
    CharToDisplay[5] = 'n';
    CharToDisplay[6] = 0x00;
    CharToDisplay[7] = 0x00;
    CharToDisplay[8] = 0x00;
    CharToDisplay[9] = 0x00;
    CharToDisplay[10] = 0x00;
    CharToDisplay[11] = 0x00;
    CharToDisplay[12] = 0x00;
    CharToDisplay[13] = 0x00;
    CharToDisplay[14] = 0x00;
    CharToDisplay[15] = 0x00;
    
    UART_1_Start();                 //Start UART (optional I/O device)
    CyGlobalIntEnable;              //Enable global interrupts    
    RCK_Write(0x0);                 //Clear RCK signal
    ClockReg_Write(0x0);            //Clear the Register's clock input
    ShiftReg_1_Init();              //Start Shift Register
    EEPROM_1_Start();               //Initialize EEPROM circuit
    CyDelay(100);                   //Short delay here, 100 msec, for EEPROM startup
    EEPROM_Address = 0x0000;        //Start address for EEPROM APIs (not actual memory addr)
    Numb_of_Char = 6;               //Test with 3 chars to start
    BlankColumns = 70 - (6 * Numb_of_Char);     //Calculate blank columns needed for flush left
    RowControl_Write(0x0);          //Set circuit for Upper Row of displays
    
    for(;;)                         //Run display loop forever...
    {        
    LED_Row_Drive = (0x01);
        
        for(CharGenRow = 1; CharGenRow <8; CharGenRow++)    //Loop for 7 rows of data
        {
            for(CharIndex = 0; CharIndex < Numb_of_Char; CharIndex++)   //Loop through all characters
            {
                CharData = 0xFF ^ EEPROM_1_ReadByte(EEPROM_Address + (8 * CharToDisplay[CharIndex]) + CharGenRow);
                ShiftReg_1_Stop();
                ShiftReg_1_WriteRegValue(CharData);
                ShiftReg_1_Start();
            
                for(ShiftIndex = 1; ShiftIndex < 7; ++ShiftIndex)
                {
                    ClockReg_Write(1u);         //Six clock pulses to SR for each char's row      
                    ClockReg_Write(0u);
                }
            }    
            for(BlankIndex = 1; BlankIndex < BlankColumns; ++BlankIndex)
            {
                ClockReg_Write(1u);         //Pulse SR to shift in blank columns      
                ClockReg_Write(0u);
            }
        FET_Ctrl_Write(LED_Row_Drive);
        G_Bar_Write(0x1);
        RCK_Write(0x1);
        RCK_Write(0x0);
        G_Bar_Write(0x0);
        LED_Row_Drive = LED_Row_Drive << 1;
        CyDelay(2);
        }        
    }
}

/* [] END OF FILE */
