/*******************************************************************************
* File Name: BitStrobe_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "BitStrobe.h"

/* Check for removal by optimization */
#if !defined(BitStrobe_Sync_ctrl_reg__REMOVED)

static BitStrobe_BACKUP_STRUCT  BitStrobe_backup = {0u};

    
/*******************************************************************************
* Function Name: BitStrobe_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void BitStrobe_SaveConfig(void) 
{
    BitStrobe_backup.controlState = BitStrobe_Control;
}


/*******************************************************************************
* Function Name: BitStrobe_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void BitStrobe_RestoreConfig(void) 
{
     BitStrobe_Control = BitStrobe_backup.controlState;
}


/*******************************************************************************
* Function Name: BitStrobe_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void BitStrobe_Sleep(void) 
{
    BitStrobe_SaveConfig();
}


/*******************************************************************************
* Function Name: BitStrobe_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void BitStrobe_Wakeup(void)  
{
    BitStrobe_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
