/*******************************************************************************
* File Name: ClockReg_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "ClockReg.h"

/* Check for removal by optimization */
#if !defined(ClockReg_Sync_ctrl_reg__REMOVED)

static ClockReg_BACKUP_STRUCT  ClockReg_backup = {0u};

    
/*******************************************************************************
* Function Name: ClockReg_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void ClockReg_SaveConfig(void) 
{
    ClockReg_backup.controlState = ClockReg_Control;
}


/*******************************************************************************
* Function Name: ClockReg_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void ClockReg_RestoreConfig(void) 
{
     ClockReg_Control = ClockReg_backup.controlState;
}


/*******************************************************************************
* Function Name: ClockReg_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void ClockReg_Sleep(void) 
{
    ClockReg_SaveConfig();
}


/*******************************************************************************
* Function Name: ClockReg_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void ClockReg_Wakeup(void)  
{
    ClockReg_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
