/*******************************************************************************
* File Name: ControlReg1_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "ControlReg1.h"

/* Check for removal by optimization */
#if !defined(ControlReg1_Sync_ctrl_reg__REMOVED)

static ControlReg1_BACKUP_STRUCT  ControlReg1_backup = {0u};

    
/*******************************************************************************
* Function Name: ControlReg1_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void ControlReg1_SaveConfig(void) 
{
    ControlReg1_backup.controlState = ControlReg1_Control;
}


/*******************************************************************************
* Function Name: ControlReg1_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void ControlReg1_RestoreConfig(void) 
{
     ControlReg1_Control = ControlReg1_backup.controlState;
}


/*******************************************************************************
* Function Name: ControlReg1_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void ControlReg1_Sleep(void) 
{
    ControlReg1_SaveConfig();
}


/*******************************************************************************
* Function Name: ControlReg1_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void ControlReg1_Wakeup(void)  
{
    ControlReg1_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
