/*******************************************************************************
* File Name: ControlReg2_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "ControlReg2.h"

/* Check for removal by optimization */
#if !defined(ControlReg2_Sync_ctrl_reg__REMOVED)

static ControlReg2_BACKUP_STRUCT  ControlReg2_backup = {0u};

    
/*******************************************************************************
* Function Name: ControlReg2_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void ControlReg2_SaveConfig(void) 
{
    ControlReg2_backup.controlState = ControlReg2_Control;
}


/*******************************************************************************
* Function Name: ControlReg2_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void ControlReg2_RestoreConfig(void) 
{
     ControlReg2_Control = ControlReg2_backup.controlState;
}


/*******************************************************************************
* Function Name: ControlReg2_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void ControlReg2_Sleep(void) 
{
    ControlReg2_SaveConfig();
}


/*******************************************************************************
* Function Name: ControlReg2_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void ControlReg2_Wakeup(void)  
{
    ControlReg2_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
