/*******************************************************************************
* File Name: G_Bar_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "G_Bar.h"

/* Check for removal by optimization */
#if !defined(G_Bar_Sync_ctrl_reg__REMOVED)

static G_Bar_BACKUP_STRUCT  G_Bar_backup = {0u};

    
/*******************************************************************************
* Function Name: G_Bar_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void G_Bar_SaveConfig(void) 
{
    G_Bar_backup.controlState = G_Bar_Control;
}


/*******************************************************************************
* Function Name: G_Bar_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void G_Bar_RestoreConfig(void) 
{
     G_Bar_Control = G_Bar_backup.controlState;
}


/*******************************************************************************
* Function Name: G_Bar_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void G_Bar_Sleep(void) 
{
    G_Bar_SaveConfig();
}


/*******************************************************************************
* Function Name: G_Bar_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void G_Bar_Wakeup(void)  
{
    G_Bar_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
