/*******************************************************************************
* File Name: LoadReg_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "LoadReg.h"

/* Check for removal by optimization */
#if !defined(LoadReg_Sync_ctrl_reg__REMOVED)

static LoadReg_BACKUP_STRUCT  LoadReg_backup = {0u};

    
/*******************************************************************************
* Function Name: LoadReg_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void LoadReg_SaveConfig(void) 
{
    LoadReg_backup.controlState = LoadReg_Control;
}


/*******************************************************************************
* Function Name: LoadReg_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void LoadReg_RestoreConfig(void) 
{
     LoadReg_Control = LoadReg_backup.controlState;
}


/*******************************************************************************
* Function Name: LoadReg_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void LoadReg_Sleep(void) 
{
    LoadReg_SaveConfig();
}


/*******************************************************************************
* Function Name: LoadReg_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void LoadReg_Wakeup(void)  
{
    LoadReg_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
