/*******************************************************************************
* File Name: RCK_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "RCK.h"

/* Check for removal by optimization */
#if !defined(RCK_Sync_ctrl_reg__REMOVED)

static RCK_BACKUP_STRUCT  RCK_backup = {0u};

    
/*******************************************************************************
* Function Name: RCK_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void RCK_SaveConfig(void) 
{
    RCK_backup.controlState = RCK_Control;
}


/*******************************************************************************
* Function Name: RCK_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void RCK_RestoreConfig(void) 
{
     RCK_Control = RCK_backup.controlState;
}


/*******************************************************************************
* Function Name: RCK_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void RCK_Sleep(void) 
{
    RCK_SaveConfig();
}


/*******************************************************************************
* Function Name: RCK_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void RCK_Wakeup(void)  
{
    RCK_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
