/*******************************************************************************
* File Name: RowControl_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "RowControl.h"

/* Check for removal by optimization */
#if !defined(RowControl_Sync_ctrl_reg__REMOVED)

static RowControl_BACKUP_STRUCT  RowControl_backup = {0u};

    
/*******************************************************************************
* Function Name: RowControl_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void RowControl_SaveConfig(void) 
{
    RowControl_backup.controlState = RowControl_Control;
}


/*******************************************************************************
* Function Name: RowControl_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void RowControl_RestoreConfig(void) 
{
     RowControl_Control = RowControl_backup.controlState;
}


/*******************************************************************************
* Function Name: RowControl_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void RowControl_Sleep(void) 
{
    RowControl_SaveConfig();
}


/*******************************************************************************
* Function Name: RowControl_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void RowControl_Wakeup(void)  
{
    RowControl_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
