/* ========================================
 *
 * PSoC:  PSoC CY8C5888LTI-5LP
 * Kit: CY8CKIT-059
 * LED Sign-Control Software for 5-by-7 or 8-by-8 LED modules
 * LED module:  Common Anode for rows, common cathode for columns.
 * Jonathan A Titus, Herriman, UT 2018
 * 08-07-2018 at 1800H US MDT
 * Released as open-source code.
 * No restrictions on use.
 * Please acknowledge author in any derived code!
 *
 * ========================================
*/
#include "project.h"

    uint8 BlankColumns[2];          //Number of blank columns to shift out for each line
    uint8 BlankIndex;               //Counter for blank-column shifts
    uint8 CharData;
    uint8 CharGenRow;
    uint8 CharIndex;
    uint8 CharToDisplay[2][16];     //Array of ASCII characters to display for each line
    uint8 LED_Row_Drive;            //Sets the FET to drive an LED row
    uint8 LoopCount;
    uint8 Line;                     //Line 0 or 1 for messages
    uint8 Numb_of_Char[2];          //Number of characters to display in each line
    uint8 Numb_of_Lines;            //Number of lines in the sign, usually 2
    uint8 RowControl;
    uint8 ShiftIndex;
    uint8 Numb_of_LEDs;             //Number of LEDs in a display row
    uint16 EEPROM_Address;

    int main(void)
    {
    Numb_of_Char[0] = 7;
    CharToDisplay[0][0] = ' ';         //Charatcters to display, max 15 per line, line 0
    CharToDisplay[0][1] = ' ';         //You can set up the array this way instead:
    CharToDisplay[0][2] = 'H';         //uint8 CharToDisplay[0][] = "  Hello";
    CharToDisplay[0][3] = 'e';         //I used the method to the left because I can easily
    CharToDisplay[0][4] = 'l';         //see the characters and their array locations.
    CharToDisplay[0][5] = 'l';         //Many ways to solve a problem...
    CharToDisplay[0][6] = 'o';
    CharToDisplay[0][7] = ' ';         //Use a space to fill unused places in the array
    CharToDisplay[0][8] = ' ';
    CharToDisplay[0][9] = ' ';
    CharToDisplay[0][10] = ' ';
    CharToDisplay[0][11] = ' ';
    CharToDisplay[0][12] = ' ';
    CharToDisplay[0][13] = ' ';
    CharToDisplay[0][14] = ' ';
    CharToDisplay[0][15] = ' ';
    
    Numb_of_Char[1] = 10;
    CharToDisplay[1][0] = 'N';         //Charatcters to display, max 15 per line, line 1
    CharToDisplay[1][1] = 'u';
    CharToDisplay[1][2] = 't';
    CharToDisplay[1][3] = 's';
    CharToDisplay[1][4] = '+';
    CharToDisplay[1][5] = 'V';
    CharToDisplay[1][6] = 'o';
    CharToDisplay[1][7] = 'l';
    CharToDisplay[1][8] = 't';
    CharToDisplay[1][9] = 's';
    CharToDisplay[1][10] = ' ';
    CharToDisplay[1][11] = ' ';
    CharToDisplay[1][12] = ' ';
    CharToDisplay[1][13] = ' ';
    CharToDisplay[1][14] = ' ';
    CharToDisplay[1][15] = ' ';
    
    UART_1_Start();                            
    //Start UART (optional I/O device)
    CyGlobalIntEnable;                                      //Enable global interrupts    
    Numb_of_LEDs = 70;                                      //In my display 14 modules times 5 LEDs in each row
    RCK_Write(0x0);                                         //Clear RCK signal, prevent loading DR bits to output latch
    ClockReg_Write(0x0);                                    //Clear the Register's clock input
    ShiftReg_1_Init();                                      //Start Shift Register.  See API documentation.
    EEPROM_1_Start();                                       //Initialize EEPROM circuit
    CyDelay(100);                                           //Short delay here, 100 msec, for EEPROM startup
    EEPROM_Address = 0x0000;                                //Start address for EEPROM APIs (not actual memory addr)
    BlankColumns[0] = Numb_of_LEDs - (6 * Numb_of_Char[0]);   //Calculate blank columns needed for flush left line 0
    BlankColumns[1] = Numb_of_LEDs - (6 * Numb_of_Char[1]);   //Calculate blank columns needed for flush left line 1
    if (BlankColumns[0] > Numb_of_LEDs)                     //If you have too many characters to display, do not use
       BlankColumns[0] = 0;                                 //any blank spaces on that line. Instead display the last
    if (BlankColumns[1] > Numb_of_LEDs)                     //characters in the given array.  (Unsigned binary math)
       BlankColumns[1] = 0;                                 //Change Numb_of_LEDs to the number of LED in a row on your sign
    RowControl_Write(0x0);                                  //Set circuit for Upper Row of displays, line 0
    Numb_of_Lines = 2;                                      //Two lines of characters in my sign, increase or decrease as needed
    
    for(;;)                                                 //Run this display loop forever...
    {        
    LED_Row_Drive = (0x01);                                 //Set up MOSFET drivers for the first row of LEDs in both lines
    
    
        for(CharGenRow = 1; CharGenRow <8; CharGenRow++)    //Loop for 7 rows of data.  Change 8 to 9 for 8-by-8 LED modules
        {
           
            for (Line = 0; Line < Numb_of_Lines; Line++)    //Loop for two message lines
            {
                RowControl_Write(Line);                                           //Set demuxes for line 0 to start
                for(CharIndex = 0; CharIndex < Numb_of_Char[Line]; CharIndex++)   //Loop through all characters for this line
                {
                    //Get character-row bits, see article text
                    CharData = 0xFF ^ EEPROM_1_ReadByte(EEPROM_Address + (8 * CharToDisplay[Line][CharIndex]) + CharGenRow);
                    ShiftReg_1_Stop();                                  //Shift-register stop.  See API documentation
                    ShiftReg_1_WriteRegValue(CharData);                 //Load shift register
                    ShiftReg_1_Start();                                 //Start shift register
            
                    for(ShiftIndex = 1; ShiftIndex < 7; ++ShiftIndex)   //Got the bits for character in current row, so shift them out, and insert
                                                                        //and "off" bit to leave a blank column between characters.
                                                                        //Change 7 to 9 for 8-by-8 LED modules
                    {
                        ClockReg_Write(1u);                             //Send six clock pulses to SR for each char's row bits + off bit      
                        ClockReg_Write(0u);
                    }
                }    
                for(BlankIndex = 1; BlankIndex < BlankColumns[Line]; ++BlankIndex)  //To fill out the line with blank columns, flush left message
                {
                    ClockReg_Write(1u);                                             //Pulse SR to shift out blank columns      
                    ClockReg_Write(0u);
                }
        
            }
        FET_Ctrl_Write(LED_Row_Drive);          //Turn on the MOSFET for this row
        G_Bar_Write(0x1);                       //Disable SR latch outputs
        RCK_Write(0x1);                         //Load latch from shift register, short logic-1
        RCK_Write(0x0);                         //  back to logic-0
        G_Bar_Write(0x0);                       //Enable SR latch outputs
        LED_Row_Drive = LED_Row_Drive << 1;     //Shift MOSFET enable bit one position to the left for next row
        CyDelay(2);                             //2 millisec delay to avoid flicker
        }        
    }
}

/* [] END OF FILE */
