/*******************************************************************************
* File Name: StastusReg_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "StastusReg.h"

/* Check for removal by optimization */
#if !defined(StastusReg_Sync_ctrl_reg__REMOVED)

static StastusReg_BACKUP_STRUCT  StastusReg_backup = {0u};

    
/*******************************************************************************
* Function Name: StastusReg_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void StastusReg_SaveConfig(void) 
{
    StastusReg_backup.controlState = StastusReg_Control;
}


/*******************************************************************************
* Function Name: StastusReg_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void StastusReg_RestoreConfig(void) 
{
     StastusReg_Control = StastusReg_backup.controlState;
}


/*******************************************************************************
* Function Name: StastusReg_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void StastusReg_Sleep(void) 
{
    StastusReg_SaveConfig();
}


/*******************************************************************************
* Function Name: StastusReg_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void StastusReg_Wakeup(void)  
{
    StastusReg_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
