/*******************************************************************************
* File Name: StatusReg_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "StatusReg.h"

/* Check for removal by optimization */
#if !defined(StatusReg_Sync_ctrl_reg__REMOVED)

static StatusReg_BACKUP_STRUCT  StatusReg_backup = {0u};

    
/*******************************************************************************
* Function Name: StatusReg_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void StatusReg_SaveConfig(void) 
{
    StatusReg_backup.controlState = StatusReg_Control;
}


/*******************************************************************************
* Function Name: StatusReg_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void StatusReg_RestoreConfig(void) 
{
     StatusReg_Control = StatusReg_backup.controlState;
}


/*******************************************************************************
* Function Name: StatusReg_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void StatusReg_Sleep(void) 
{
    StatusReg_SaveConfig();
}


/*******************************************************************************
* Function Name: StatusReg_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void StatusReg_Wakeup(void)  
{
    StatusReg_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
